<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use OSL\Utils\Html as HtmlUtils;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;

defined('_JEXEC') or die();

HTMLHelper::_('behavior.core');

$fields = $this->form->getFields();

if (isset($fields['state']) && strtolower($fields['state']->type) == 'state')
{
	$document = Factory::getDocument();
	$rootUri  = Uri::root(true);
	$document->addScript($rootUri . '/media/com_pmform/assets/js/noconflict.min.js');
	$document->addScript($rootUri . '/media/com_pmform/assets/js/paymentform.min.js');
	$document->addScript($rootUri . '/media/com_pmform/js/admin-payment-default.min.js');

	$selectedState = $fields['state']->value;

	$document->addScriptOptions('selectedState', $selectedState);
	$document->addScriptDeclaration('var siteUrl="' . PMFormHelper::getSiteUrl() . '";');
}

$bootstrapHelper = PMFormHelper::getAdminBootstrapHelper();

$bootstrapHelper->addClassMapping('control-group', 'control-group')
	->addClassMapping('control-label', 'control-label')
	->addClassMapping('controls', 'controls');
?>
<form action="index.php?option=com_pmform&view=payments" method="post" name="adminForm" id="adminForm" class="form form-horizontal">
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('User'); ?>
	    </div>
	    <div class="controls">
	        <?php echo HtmlUtils::getUserInput($this->item->user_id); ?>
	    </div>
	</div>
	<?php
	    $this->form->removeField('amount');

	    echo $this->form->render(true, $bootstrapHelper);
	?>
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('PF_TOTAL_AMOUNT'); ?>
	    </div>
	    <div class="controls">
            <?php
                $input = '<input type="text" class="input-small form-control" name="total_amount" value="' . ($this->item->total_amount > 0 ? round($this->item->total_amount, 2) : "") . '" size="7" />';
                echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
            ?>
	    </div>
	</div>
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('PF_DISCOUNT_AMOUNT'); ?>
	    </div>
	    <div class="controls">
		    <?php
                $input = '<input type="text" class="input-small form-control" name="discount_amount" value="' . ($this->item->discount_amount > 0 ? round($this->item->discount_amount, 2) : "") . '" size="7" />';
                echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
		    ?>
	    </div>
	</div>
	<div class="control-group">
		<div class="control-label">
			<?php echo  Text::_('PF_TAX_AMOUNT'); ?>
		</div>
		<div class="controls">
			<?php
                $input = '<input type="text" class="input-small form-control" name="tax_amount" value="' . ($this->item->tax_amount > 0 ? round($this->item->tax_amount, 2) : "") . '" size="7" />';
                echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
			?>
		</div>
	</div>
	<div class="control-group">
		<div class="control-label">
			<?php echo  Text::_('PF_LATE_FEE'); ?>
		</div>
		<div class="controls">
			<?php
                $input = '<input type="text" class="input-small form-control" name="late_fee" value="' . ($this->item->late_fee > 0 ? round($this->item->late_fee, 2) : "") . '" size="7" />';
                echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
			?>
		</div>
	</div>
	<?php
	if ($this->item->payment_processing_fee > 0)
	{
	?>
	    <div class="control-group">
	        <div class="control-label">
		        <?php echo  Text::_('PF_PAYMENT_FEE'); ?>
	        </div>
	        <div class="controls">
		        <?php
                    $input = '<input type="text" class="input-small form-control" name="payment_processing_fee" value="' . ($this->item->payment_processing_fee > 0 ? round($this->item->payment_processing_fee, 2) : "") . '" size="7" />';
                    echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
		        ?>
	        </div>
	    </div>
	<?php
	}
	?>
	<div class="control-group">
		<div class="control-label">
			<?php echo  Text::_('PF_GROSS_AMOUNT'); ?>
		</div>
		<div class="controls">
			<?php
                $input = '<input type="text" class="input-small form-control" name="gross_amount" value="' . ($this->item->gross_amount > 0 ? round($this->item->gross_amount, 2) : "") . '" size="7" />';
                echo $bootstrapHelper->getPrependAddon($input, $this->config->currency_symbol);
			?>
		</div>
	</div>
	<?php
	if (!empty($this->item->coupon_code))
	{
	?>
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('Coupon Code'); ?>
	    </div>
	    <div class="controls">
	        <?php echo $this->item->coupon_code ; ?>
	    </div>
	</div>
	<?php
	}
	?>
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('Payment method'); ?>
	    </div>
	    <div class="controls">
	        <?php echo $this->lists['payment_method']; ?>
	    </div>
	</div>
	<div class="control-group">
	    <div class="control-label">
	        <?php echo  Text::_('Transaction ID'); ?>
	    </div>
	    <div class="controls">
	        <input type="text" class="form-control" size="50" name="transaction_id" id="transaction_id" value="<?php echo $this->item->transaction_id ; ?>" />
	    </div>
	</div>
	<div class="control-group">
	     <div class="control-label">
	         <?php echo Text::_('Paid'); ?>
	     </div>
	     <div class="controls">
	         <?php echo $this->lists['published']; ?>
	    </div>
	</div>
	<div class="clearfix"></div>
	<input type="hidden" name="id" value="<?php echo $this->item->id; ?>" />
	<input type="hidden" name="form_id" value="<?php echo $this->formId; ?>" />
	<input type="hidden" name="task" value="" />
	<?php echo HTMLHelper::_( 'form.token' ); ?>
</form>
