<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Filesystem\File;
use Joomla\CMS\Filesystem\Folder;
use Joomla\CMS\Language\Multilanguage;

/**
 * Change the db structure of the previous version
 *
 */
class com_pmformInstallerScript
{
	public static $languageFiles = ['en-GB.com_pmform.ini'];

	/**
	 * Method to run before installing the component
	 */
	public function preflight($type, $parent)
	{
		if (!version_compare(JVERSION, '3.9.0', 'ge'))
		{
			JError::raiseWarning(null, 'Cannot install Payment Form in a Joomla release prior to 3.4.0');

			return false;
		}

		//Backup the old language files
		foreach (self::$languageFiles as $languageFile)
		{
			if (File::exists(JPATH_ROOT . '/language/en-GB/' . $languageFile))
			{
				File::copy(JPATH_ROOT . '/language/en-GB/' . $languageFile, JPATH_ROOT . '/language/en-GB/bak.' . $languageFile);
			}
		}

		$deleteFolders = [
			JPATH_ROOT . '/components/com_pmform/assets',
			JPATH_ROOT . '/components/com_pmform/models',
			JPATH_ROOT . '/components/com_pmform/views',
			JPATH_ROOT . '/components/com_pmform/controller',
			JPATH_ROOT . '/components/com_pmform/model',
			JPATH_ROOT . '/components/com_pmform/view',
			JPATH_ROOT . '/components/com_pmform/helper',
			JPATH_ROOT . '/components/com_pmform/emailtemplates',
			JPATH_ADMINISTRATOR . '/components/com_pmform/assets',
			JPATH_ADMINISTRATOR . '/components/com_pmform/controllers',
			JPATH_ADMINISTRATOR . '/components/com_pmform/models',
			JPATH_ADMINISTRATOR . '/components/com_pmform/views',
			JPATH_ADMINISTRATOR . '/components/com_pmform/tables',
			JPATH_ADMINISTRATOR . '/components/com_pmform/controller',
			JPATH_ADMINISTRATOR . '/components/com_pmform/model',
			JPATH_ADMINISTRATOR . '/components/com_pmform/view',
			JPATH_ADMINISTRATOR . '/components/com_pmform/table',
		];

		$deleteFiles = [
			JPATH_ROOT . '/components/com_pmform/ipn_logs.txt',
			JPATH_ROOT . '/media/com_pmform/.htaccess',
			JPATH_ADMINISTRATOR . '/components/com_pmform/controller.php',
			JPATH_ADMINISTRATOR . '/components/com_pmform/loader.php',
		];

		foreach ($deleteFolders as $folder)
		{
			if (Folder::exists($folder))
			{
				Folder::delete($folder);
			}
		}

		foreach ($deleteFiles as $file)
		{
			if (File::exists($file))
			{
				File::delete($file);
			}
		}
	}

	/**
	 * method to install the component
	 *
	 * @return void
	 */
	public function install($parent)
	{
		$this->updateDatabaseSchema();
	}

	public function update($parent)
	{
		$this->updateDatabaseSchema();
	}

	public function updateDatabaseSchema()
	{
		require_once JPATH_ROOT . '/components/com_pmform/Helper/Helper.php';

		$db = Factory::getDbo();

		// Load states database
		$sqlFile = JPATH_ADMINISTRATOR . '/components/com_pmform/sql/states.pmform.sql';

		self::executeSqlFile($sqlFile);

		//Load config config data
		$sql = 'SELECT COUNT(*) FROM #__pf_configs';
		$db->setQuery($sql);
		$total = $db->loadResult();

		if (!$total)
		{
			$configSql = JPATH_ADMINISTRATOR . '/components/com_pmform/sql/config.pmform.sql';
			self::executeSqlFile($configSql);

			//Update date_format config option
			$sql = 'UPDATE #__pf_configs SET config_value="m-d-Y" WHERE config_key="date_format"';
			$db->setQuery($sql);
			$db->execute();

		}

		// Convert ROW_FORMAT to dynamic

		$tables = [
			'#__pf_forms',
			'#__pf_fields',
			'#__pf_payments',
		];

		try
		{
			foreach ($tables as $table)
			{
				$query = "ALTER TABLE `$table` ROW_FORMAT = DYNAMIC";
				$db->setQuery($query)
					->execute();
			}
		}
		catch (Exception $e)
		{

		}

		//Version 1.1 : Add fields to form
		$fields = array_keys($db->getTableColumns('#__pf_forms'));

		if (!in_array('currency_code', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `currency_code` VARCHAR(255)";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('currency_symbol', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `currency_symbol` VARCHAR(255)";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('user_registration', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `user_registration` INT NOT NULL DEFAULT '2'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('show_login_box', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `show_login_box` INT NOT NULL DEFAULT '2'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('payment_complete_url', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `payment_complete_url` VARCHAR(255)";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('article_id', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `article_id` INT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('tax_rate', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `tax_rate` DECIMAL( 10, 2 ) NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('access', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `access` TINYINT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('enter_amount', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `enter_amount` TINYINT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('fee_calculation_script', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `fee_calculation_script` TEXT NULL AFTER  `enter_amount`";
			$db->setQuery($sql)
				->execute();
		}

		//Version 1.2 : Add some extra veriables
		if (!in_array('form_layout', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `form_layout` VARCHAR( 50 ) NULL ;";
			$db->setQuery($sql)
				->execute();
		}

		//Added attachment support from version 1.7.0
		if (!in_array('attachment', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_forms` ADD  `attachment` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql)
				->execute();

			//Need to create com_eventbooking folder under media folder
			if (!Folder::exists(JPATH_ROOT . '/media/com_pmform'))
			{
				Folder::create(JPATH_ROOT . '/media/com_pmform');
			}
		}

		//Version 2.1, coupon code support
		if (!in_array('enable_coupon', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `enable_coupon` TINYINT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}
		//Version 2.2, payment methods selection
		if (!in_array('payment_methods', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `payment_methods` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('user_email_body_offline', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `user_email_body_offline` TEXT NULL;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('thanks_message_offline', $fields))
		{
			$sql = "ALTER TABLE `#__pf_forms` ADD `thanks_message_offline` TEXT NULL;";
			$db->setQuery($sql)
				->execute();
		}

		$fields = array_keys($db->getTableColumns('#__pf_payments'));

		if (!in_array('order_number', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `order_number` VARCHAR( 50 ) NULL DEFAULT '';";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('language', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `language` VARCHAR( 50 ) NULL DEFAULT '*';";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('eventsbooking_coupon_id', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `eventsbooking_coupon_id` INT NULL DEFAULT '0';";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('ip_address', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `ip_address` VARCHAR( 50 ) NULL;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('payment_amount', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `payment_amount` DECIMAL( 10, 2 ) NULL DEFAULT '0';";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('payment_currency', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `payment_currency` VARCHAR( 15 ) NULL;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('tax_amount', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `tax_amount` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('late_fee', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `late_fee` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('discount_amount', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `discount_amount` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('payment_processing_fee', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `payment_processing_fee` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('coupon_id', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `coupon_id` INT NOT NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('total_amount', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `total_amount` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();

			$sql = "ALTER TABLE  `#__pf_payments` ADD  `gross_amount` DECIMAL( 10, 2 ) NULL DEFAULT '0' ;";
			$db->setQuery($sql)
				->execute();

			//Update the amount field
			$sql = 'UPDATE #__pf_payments SET `total_amount` = `amount`';
			$db->setQuery($sql)
				->execute();

			$sql = 'UPDATE #__pf_payments SET `gross_amount` = `total_amount` - `discount_amount`';
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('user_password', $fields))
		{
			$sql = "ALTER TABLE `#__pf_payments` ADD `user_password` VARCHAR( 225 ) NULL ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('username', $fields))
		{
			$sql = "ALTER TABLE `#__pf_payments` ADD `username` VARCHAR( 225 ) NULL ;";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('params', $fields))
		{
			$sql = "ALTER TABLE `#__pf_payments` ADD `params` TEXT NULL ;";
			$db->setQuery($sql)
				->execute();
		}

		// Invoice number
		if (!in_array('invoice_number', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_payments` ADD  `invoice_number` INT NOT NULL DEFAULT  '0';";
			$db->setQuery($sql);
			$db->execute();

			//Update Invoice Number field for existing payment records
			$sql = 'SELECT id FROM #__pf_payments WHERE published=1 OR payment_method LIKE "%os_offline%" ORDER BY id';
			$db->setQuery($sql);
			$rows = $db->loadObjectList();
			if (count($rows))

			{
				$start = 1;
				foreach ($rows as $row)
				{
					$sql = 'UPDATE #__pf_payments SET invoice_number=' . $start . ' WHERE id=' . $row->id;
					$db->setQuery($sql);
					$db->execute();
					$start++;
				}
			}
			//Need to insert default data into the system
			$invoiceFormat = '<table border="0" width="100%" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td align="left" width="100%">
			<table border="0" width="100%" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td width="100%">
			<table style="width: 100%;" border="0" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td align="left" valign="top" width="50%">
			<table style="width: 100%;" border="0" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td align="left" width="50%">Company Name:</td>
			<td align="left">Ossolution Team</td>
			</tr>
			<tr>
			<td align="left" width="50%">URL:</td>
			<td align="left">http://www.joomdonation.com</td>
			</tr>
			<tr>
			<td align="left" width="50%">Phone:</td>
			<td align="left">84-972409994</td>
			</tr>
			<tr>
			<td align="left" width="50%">E-mail:</td>
			<td align="left">contact@joomdonation.com</td>
			</tr>
			<tr>
			<td align="left" width="50%">Address:</td>
			<td align="left">Lang Ha - Ba Dinh - Ha Noi</td>
			</tr>
			</tbody>
			</table>
			</td>
			<td align="right" valign="middle" width="50%"><img style="border: 0;" src="media/com_pmform/assets/icons/invoice_logo.png" alt="" /></td>
			</tr>
			<tr>
			<td colspan="2" align="left" width="100%">
			<table style="width: 100%;" border="0" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td align="left" valign="top" width="50%">
			<table style="width: 100%;" border="0" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td style="background-color: #d6d6d6;" colspan="2" align="left">
			<h4 style="margin: 0px;">Customer Information</h4>
			</td>
			</tr>
			<tr>
			<td align="left" width="50%">Name:</td>
			<td align="left">[NAME]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Company:</td>
			<td align="left">[ORGANIZATION]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Phone:</td>
			<td align="left">[PHONE]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Email:</td>
			<td align="left">[EMAIL]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Address:</td>
			<td align="left">[ADDRESS], [CITY], [STATE], [COUNTRY]</td>
			</tr>
			</tbody>
			</table>
			</td>
			<td align="left" valign="top" width="50%">
			<table style="width: 100%;" border="0" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td style="background-color: #d6d6d6;" colspan="2" align="left">
			<h4 style="margin: 0px;">Invoice Information</h4>
			</td>
			</tr>
			<tr>
			<td align="left" width="50%">Invoice Number:</td>
			<td align="left">[INVOICE_NUMBER]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Invoice Date:</td>
			<td align="left">[INVOICE_DATE]</td>
			</tr>
			<tr>
			<td align="left" width="50%">Invoice Status:</td>
			<td align="left">[INVOICE_STATUS]</td>
			</tr>
			</tbody>
			</table>
			</td>
			</tr>
			</tbody>
			</table>
			</td>
			</tr>
			<tr>
			<td style="background-color: #d6d6d6;" colspan="2" align="left">
			<h4 style="margin: 0px;">Order Items</h4>
			</td>
			</tr>
			<tr>
			<td colspan="2" align="left" width="100%">
			<table border="0" width="100%" cellspacing="0" cellpadding="2">
			<tbody>
			<tr>
			<td align="left" valign="top" width="10%">#</td>
			<td align="left" valign="top" width="60%">Name</td>
			<td align="right" valign="top" width="20%">Price</td>
			<td align="left" valign="top" width="10%">Sub Total</td>
			</tr>
			<tr>
			<td align="left" valign="top" width="10%">1</td>
			<td align="left" valign="top" width="60%">[ITEM_NAME]</td>
			<td align="right" valign="top" width="20%">[ITEM_AMOUNT]</td>
			<td align="left" valign="top" width="10%">[ITEM_SUB_TOTAL]</td>
			</tr>
			<tr>
			<td colspan="3" align="right" valign="top" width="90%">Discount :</td>
			<td align="left" valign="top" width="10%">[DISCOUNT_AMOUNT]</td>
			</tr>
			<tr>
			<td colspan="3" align="right" valign="top" width="90%">Subtotal :</td>
			<td align="left" valign="top" width="10%">[SUB_TOTAL]</td>
			</tr>
			<tr>
			<td colspan="3" align="right" valign="top" width="90%">Total :</td>
			<td align="left" valign="top" width="10%">[TOTAL_AMOUNT]</td>
			</tr>
			</tbody>
			</table>
			</td>
			</tr>
			</tbody>
			</table>
			</td>
			</tr>
			</tbody>
			</table>
			</td>
			</tr>
			</tbody>
			</table>';
			$sql           = 'INSERT INTO #__pf_configs(config_key, config_value) VALUES ("invoice_format", ' . $db->quote($invoiceFormat) . ')';
			$db->setQuery($sql);
			$db->execute();

			$query = $db->getQuery(true);
			$query->insert('#__pf_configs')
				->columns('config_key, config_value')
				->values('"activate_invoice_feature", 0')
				->values('"send_invoice_to_customer", 0')
				->values('"invoice_start_number", 1')
				->values('"invoice_prefix", "IV"')
				->values('"invoice_number_length", 5');
			$db->setQuery($query);
			$db->execute();
		}

		//Change data type of description field to allows longer text

		$sql = 'ALTER TABLE `#__pf_fields` CHANGE  `description`  `description` TEXT NULL;';
		$db->setQuery($sql);
		$db->execute();

		$fields = array_keys($db->getTableColumns('#__pf_fields'));

		if (!in_array('min', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `min` INT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('max', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `max` INT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('step', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `step` INT NOT NULL DEFAULT '0'";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('populate_from_previous_payment', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `populate_from_previous_payment` TINYINT NOT NULL DEFAULT '1' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('server_validation_rules', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `server_validation_rules` VARCHAR( 250 ) NULL ";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('validation_error_message', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `validation_error_message` VARCHAR( 250 ) NULL ";
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('access', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `access` TINYINT NOT NULL DEFAULT '1' ";
			$db->setQuery($sql);
			$db->execute();

			$sql = 'UPDATE #__pf_fields SET `access` = 1';
			$db->setQuery($sql)
				->execute();
		}

		if (!in_array('filterable', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `filterable` TINYINT NOT NULL DEFAULT '0' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('is_searchable', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `is_searchable` TINYINT NOT NULL DEFAULT '0' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('receive_confirmation_email', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `receive_confirmation_email` TINYINT NOT NULL DEFAULT '0' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('datatype_validation', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `datatype_validation` TINYINT NOT NULL DEFAULT '0' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('show_on_email', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `show_on_email` TINYINT NOT NULL DEFAULT '1' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('show_on_export', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `show_on_export` TINYINT NOT NULL DEFAULT '1' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('fee_formula', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `fee_formula` VARCHAR( 250 ) NULL ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('field_mapping', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `field_mapping` VARCHAR( 50 ) NULL ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('is_core', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `is_core` TINYINT NOT NULL DEFAULT '0' ";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('options_text', $fields))
		{
			$sql = "ALTER TABLE `#__pf_fields` ADD `options_text` TEXT NULL;";
			$db->setQuery($sql);
			$db->execute();

			$sql = "UPDATE #__pf_fields SET `options_text` = `values`";
			$db->setQuery($sql);
			$db->execute();
		}

		//We will need to insert core field
		$sql = 'SELECT COUNT(*) FROM #__pf_fields WHERE is_core = 1';
		$db->setQuery($sql);
		$total = $db->loadResult();
		if (!$total)
		{
			$sql = 'SELECT * FROM #__pf_fields ORDER BY id DESC ';
			$db->setQuery($sql);
			$rows = $db->loadObjectList();
			for ($i = 0, $n = count($rows); $i < $n; $i++)
			{
				$row = $rows[$i];
				$sql = 'UPDATE #__pf_fields SET id = id + 14 WHERE id=' . $row->id;
				$db->setQuery($sql);
				$db->execute();
			}
			//Update total custom field
			$sql = 'UPDATE #__pf_fields SET id = id + 14';
			$db->setQuery($sql);
			$db->execute();

			$sql = 'SELECT id FROM #__pf_forms';
			$db->setQuery($sql);
			$formIds = $db->loadColumn();
			$sql     = 'SELECT id FROM #__pf_fields WHERE form_id=0';
			$db->setQuery($sql);
			$fieldIds = $db->loadColumn();
			if (count($fieldIds))
			{
				foreach ($fieldIds as $fieldId)
				{
					for ($i = 0, $n = count($formIds); $i < $n; $i++)
					{
						$formId = $formIds[$i];
						$sql    = 'INSERT INTO #__pf_form_fields(form_id, field_id) VALUES(' . $formId . ',' . $fieldId . ')';
						$db->setQuery($sql);
						$db->execute();
					}
				}
			}
			$sql = 'SELECT id, form_id FROM #__pf_fields WHERE form_id > 0';
			$db->setQuery($sql);
			$fields = $db->loadObjectList();
			if (count($fields))
			{
				foreach ($fields as $field)
				{
					$fieldId = $field->id;
					$formId  = $field->form_id;
					$sql     = 'INSERT INTO #__pf_form_fields(form_id, field_id) VALUES(' . $formId . ',' . $fieldId . ')';
					$db->setQuery($sql);
					$db->execute();
				}
			}
			//Update the auto increament value
			$prefix = $db->getPrefix();
			$sql    = "SHOW TABLE STATUS LIKE  '#__pf_fields'";
			$sql    = str_replace('#__', $prefix, $sql);
			$db->setQuery($sql);
			$row            = $db->loadObject();
			$autoIncreament = (int) $row->Auto_increment;
			$autoIncreament += 14;
			$sql            = 'ALTER TABLE #__pf_fields AUTO_INCREMENT = ' . $autoIncreament;
			$db->setQuery($sql);
			$db->execute();
			//Insert core fields into database
			$coreFieldsSql = JPATH_ADMINISTRATOR . '/components/com_pmform/sql/core_fields.pmform.sql';
			self::executeSqlFile($coreFieldsSql);

			//Path upload
			$pathUpload = OSSolution\PaymentForm\Site\Helper\Helper::getConfigValue('path_upload');

			if (!$pathUpload)
			{
				$pathUpload = 'images/com_pmform';
				OSSolution\PaymentForm\Site\Helper\Helper::saveConfigValue('path_upload', $pathUpload);
			}

			if (!Folder::exists(JPATH_ROOT . '/' . $pathUpload))
			{
				Folder::create(JPATH_ROOT . '/' . $pathUpload);
			}

			if (!File::exists(JPATH_ROOT . '/' . $pathUpload . '/.htaccess'))
			{
				File::copy(JPATH_ROOT . '/administrator/components/com_pmform/htaccess.txt', JPATH_ROOT . '/' . $pathUpload . '/.htaccess');
			}
		}

		//Need to check and generate data for plugins table
		$sql = 'SELECT COUNT(*) FROM #__pf_payment_plugins';
		$db->setQuery($sql);
		$total = $db->loadResult();
		if (!$total)
		{
			$configSql = JPATH_ADMINISTRATOR . '/components/com_pmform/sql/plugins.pmform.sql';
			self::executeSqlFile($configSql);
		}

		## Alter custom field table

		$fields = array_keys($db->getTableColumns('#__pf_fields'));

		if (!in_array('datatype_validation', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `datatype_validation` TINYINT NOT NULL DEFAULT  '0' ;";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('show_on_payments_list', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `show_on_payments_list` TINYINT NOT NULL DEFAULT  '0' ;";
			$db->setQuery($sql);
			$db->execute();

			$query = $db->getQuery(true);
			$query->update('#__pf_fields')
				->set('show_on_payments_list = 1')
				->where('name IN (' . implode(',', $db->quote(['first_name', 'last_name', 'organization'])) . ')');
			$db->setQuery($query)
				->execute();
		}

		if (!in_array('extra_attributes', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `extra_attributes` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('max_length', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `max_length` INT NOT NULL DEFAULT  '0';";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('place_holder', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD   `place_holder` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql);
			$db->execute();
		}
		if (!in_array('multiple', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `multiple` TINYINT NOT NULL DEFAULT  '0';";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('validation_rules', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `validation_rules` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql);
			$db->execute();
		}
		if (!in_array('validation_error_message', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `validation_error_message` VARCHAR( 255 ) NULL;";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('field_mapping', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `field_mapping` VARCHAR( 100 ) NULL;";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('depend_on_field_id', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `depend_on_field_id` INT NOT NULL DEFAULT '0';";
			$db->setQuery($sql);
			$db->execute();
		}

		if (!in_array('depend_on_options', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `depend_on_options` TEXT NULL;";
			$db->setQuery($sql);
			$db->execute();
		}
		if (!in_array('fieldtype', $fields))
		{
			$sql = "ALTER TABLE  `#__pf_fields` ADD  `fieldtype` VARCHAR( 50 ) NULL;";
			$db->setQuery($sql);
			$db->execute();

			$typeMapping = [
				0 => 'Text',
				1 => 'Textarea',
				2 => 'List',
				3 => 'Checkboxes',
				4 => 'Radio',
				5 => 'Date',
				6 => 'Heading',
				7 => 'Message',
				9 => 'File',
			];

			foreach ($typeMapping as $key => $value)
			{
				$sql = "UPDATE #__pf_fields SET fieldtype='$value' WHERE field_type='$key'";
				$db->setQuery($sql);
				$db->execute();
			}

			$sql = "UPDATE #__pf_fields SET fieldtype='List', multiple=1 WHERE field_type='8'";
			$db->setQuery($sql);
			$db->execute();

			$sql = 'UPDATE #__pf_fields SET fieldtype="Countries" WHERE name="country"';
			$db->setQuery($sql);
			$db->execute();

			//MySql, convert data to Json
			$sql = 'SELECT id, field_value FROM #__pf_field_value WHERE field_id IN (SELECT id FROM #__pf_fields WHERE field_type=3 OR field_type=8)';
			$db->setQuery($sql);
			$rowFieldValues = $db->loadObjectList();
			if (count($rowFieldValues))
			{
				foreach ($rowFieldValues as $rowFieldValue)
				{
					$fieldValue = $rowFieldValue->field_value;
					if (strpos($fieldValue, ',') !== false)
					{
						$fieldValue = explode(',', $fieldValue);
					}
					$fieldValue = json_encode($fieldValue);
					$sql        = 'UPDATE #__pf_field_value SET field_value=' . $db->quote($fieldValue) . ' WHERE id=' . $rowFieldValue->id;
					$db->setQuery($sql);
					$db->execute();
				}
			}

			$config = OSSolution\PaymentForm\Site\Helper\Helper::getConfig();

			if ($config->display_state_dropdown)
			{
				$sql = 'UPDATE #__pf_fields SET fieldtype="State" WHERE name="state"';
				$db->setQuery($sql);
				$db->execute();
			}

			//The amount field, need a special settings
			$sql = 'UPDATE #__pf_fields SET fee_field = 1, datatype_validation= 2, validation_rules="validate[required,custom[number]]", fee_formula="[FIELD_VALUE]" WHERE name="amount"';
			$db->setQuery($sql);
			$db->execute();

			//Update email field
			$sql = 'UPDATE #__pf_fields SET datatype_validation=3, validation_rules="validate[required,custom[email],ajax[ajaxEmailCall]]" WHERE name="email"';
			$db->setQuery($sql);
			$db->execute();
		}
		//Need to update other things

		$sql = "SELECT id, validation_rules FROM #__pf_fields WHERE required = 1";
		$db->setQuery($sql);
		$fields = $db->loadObjectList();
		foreach ($fields as $field)
		{
			if (empty($field->validation_rules))
			{
				$sql = 'UPDATE #__pf_fields SET validation_rules = "validate[required]" WHERE id=' . $field->id;
				$db->setQuery($sql);
				$db->execute();
			}
		}
		//Make sure validation is empty when required=0
		$sql = 'UPDATE #__pf_fields SET validation_rules = "" WHERE required=0 AND validation_rules="validate[required]"';
		$db->setQuery($sql);
		$db->execute();

		// Currency configuration
		$query = $db->getQuery(true);
		$query->select('COUNT(*)')
			->from('#__pf_configs')
			->where('config_key = "currency_code"');
		$db->setQuery($query);
		$total = $db->loadResult();

		if (empty($total))
		{
			$query->clear()
				->select('name, params')
				->from('#__pf_payment_plugins')
				->where('published = 1');
			$db->setQuery($query);
			$plugins = $db->loadObjectList('name');

			if (isset($plugins['os_paypal']))
			{
				$params       = new JRegistry($plugins['os_paypal']->params);
				$currencyCode = $params->get('paypal_currency', 'USD');
			}
			elseif (isset($plugins['os_paypal_pro']))
			{
				$params       = new JRegistry($plugins['os_paypal_pro']->params);
				$currencyCode = $params->get('paypal_pro_currency', 'USD');
			}
			elseif ($plugins['os_payflowpro'])
			{
				$params       = new JRegistry($plugins['os_payflowpro']->params);
				$currencyCode = $params->get('payflow_currency', 'USD');
			}
			else
			{
				$currencyCode = 'USD';
			}

			$query->clear()
				->insert('#__pf_configs')
				->columns('config_key, config_value')
				->values('"currency_code", "' . $currencyCode . '"');
			$db->setQuery($query);
			$db->execute();
		}

		$query->clear()
			->update('#__extensions')
			->set('enabled = 1')
			->where('element = "paymentform"')
			->where('folder = "installer"');
		$db->setQuery($query)
			->execute();


		$fields = array_keys($db->getTableColumns('#__pf_field_value'));

		if (!in_array('field_value_text', $fields))
		{
			$sql = "ALTER TABLE `#__pf_field_value` ADD `field_value_text` TEXT NULL;";
			$db->setQuery($sql);
			$db->execute();

			$sql = "UPDATE `#__pf_field_value` SET `field_value_text` = `field_value`";
			$db->setQuery($sql)
				->execute();
		}

		// Setup database schema to support multilingual
		if (Multilanguage::isEnabled())
		{
			OSSolution\PaymentForm\Site\Helper\Helper::setupMultilingual();
		}
	}


	/**
	 * Method to run after installing the component
	 */
	public function postflight($type, $parent)
	{
		//Restore the modified language strings by merging to language files
		$registry = new JRegistry();
		foreach (self::$languageFiles as $languageFile)
		{
			$backupFile  = JPATH_ROOT . '/language/en-GB/bak.' . $languageFile;
			$currentFile = JPATH_ROOT . '/language/en-GB/' . $languageFile;

			if (File::exists($currentFile) && File::exists($backupFile))
			{
				$registry->loadFile($currentFile, 'INI');
				$currentItems = $registry->toArray();
				$registry->loadFile($backupFile, 'INI');
				$backupItems = $registry->toArray();
				$items       = array_merge($currentItems, $backupItems);
				$content     = "";

				foreach ($items as $key => $value)
				{
					$content .= "$key=\"$value\"\n";
				}

				File::write($currentFile, $content);

				//Delete the backup file
				File::delete($backupFile);
			}
		}

		//Create a blank css file
		if (!File::exists(JPATH_ROOT . '/media/com_pmform/assets/css/custom.css'))
		{
			$fp = fopen(JPATH_ROOT . '/media/com_pmform/assets/css/custom.css', 'w');
			fclose($fp);
		}
	}

	/**
	 * Execute queries contained in a SQL file
	 *
	 * @param   string  $file  Path to the file contains queries need to be executed
	 */
	public static function executeSqlFile($file)
	{
		$db      = Factory::getDbo();
		$sql     = file_get_contents($file);
		$queries = $db->splitSql($sql);

		foreach ($queries as $query)
		{
			$query = trim($query);

			if ($query != '' && $query[0] != '#')
			{
				$db->setQuery($query)
					->execute();
			}
		}
	}
}
