<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

namespace OSSolution\PaymentForm\Site\Helper;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;

defined('_JEXEC') or die;

class Jquery
{
	public static function colorbox()
	{
		static $loaded;

		if ($loaded === true)
		{
			return;
		}

		HTMLHelper::_('jquery.framework');

		$rootUri  = Uri::root(true);
		$document = Factory::getDocument();
		$document->addStyleSheet($rootUri . '/media/com_pmform/assets/js/colorbox/colorbox.min.css')
			->addScript($rootUri . '/media/com_pmform/assets/js/colorbox/jquery.colorbox.min.js');

		$activeLanguageTag   = Factory::getLanguage()->getTag();
		$allowedLanguageTags = ['ar-AA', 'bg-BG', 'ca-ES', 'cs-CZ', 'da-DK', 'de-DE', 'el-GR', 'es-ES', 'et-EE',
			'fa-IR', 'fi-FI', 'fr-FR', 'he-IL', 'hr-HR', 'hu-HU', 'it-IT', 'ja-JP', 'ko-KR', 'lv-LV', 'nb-NO', 'nl-NL',
			'pl-PL', 'pt-BR', 'ro-RO', 'ru-RU', 'sk-SK', 'sr-RS', 'sv-SE', 'tr-TR', 'uk-UA', 'zh-CN', 'zh-TW',
		];

		/// English is bundled into the source therefore we don't have to load it.
		if (in_array($activeLanguageTag, $allowedLanguageTags))
		{
			$document->addScript($rootUri . '/media/com_pmform/assets/js/colorbox/i18n/jquery.colorbox-' . $activeLanguageTag . '.js');
		}

		$loaded = true;
	}

	/**
	 * validate form
	 */
	public static function validateForm()
	{
		static $loaded = false;

		if ($loaded)
		{
			return;
		}

		$config = Helper::getConfig();
		$formId = Factory::getApplication()->input->getInt('form_id');

		$dateFormat = $config->date_field_format ? $config->date_field_format : '%Y-%m-%d';
		$dateFormat = str_replace('%', '', $dateFormat);

		$humanFormat = str_replace('Y', 'YYYY', $dateFormat);
		$humanFormat = str_replace('m', 'MM', $humanFormat);
		$humanFormat = str_replace('d', 'DD', $humanFormat);

		$separator          = '';
		$possibleSeparators = ['.', '-', '/'];

		foreach ($possibleSeparators as $possibleSeparator)
		{
			if (strpos($dateFormat, $possibleSeparator) !== false)
			{
				$separator = $possibleSeparator;
				break;
			}
		}

		$dateParts = explode($separator, $dateFormat);

		$yearIndex  = array_search('Y', $dateParts);
		$monthIndex = array_search('m', $dateParts);
		$dayIndex   = array_search('d', $dateParts);

		$regex = $dateFormat;
		$regex = str_replace($separator, '[\\' . $separator . ']', $regex);
		$regex = str_replace('d', '(0?[1-9]|[12][0-9]|3[01])', $regex);
		$regex = str_replace('Y', '(\d{4})', $regex);
		$regex = str_replace('m', '(0?[1-9]|1[012])', $regex);
		$regex = 'var pattern = new RegExp(/^' . $regex . '$/);';

		$rootUri = Uri::root(true);
		Factory::getDocument()->addStyleSheet($rootUri . '/media/com_pmform/assets/js/validate/css/validationEngine.jquery.min.css')
			->addScriptDeclaration("
			var yearPartIndex = $yearIndex;
			var monthPartIndex = $monthIndex;
			var dayPartIndex = $dayIndex;
			var customDateFormat = '$dateFormat';
			$regex
		")
			->addScriptOptions('humanFormat', $humanFormat)
			->addScriptOptions('rootUri', $rootUri)
			->addScriptOptions('formId', $formId)
			->addScript($rootUri . '/media/com_pmform/assets/js/validate/js/jquery.validationEngine-lang.min.js')
			->addScript($rootUri . '/media/com_pmform/assets/js/validate/js/jquery.validationEngine.min.js');
		$languageItems = [
			'PF_VALIDATION_FIELD_REQUIRED',
			'PF_VALIDATION_PLEASE_SELECT_AN_OPTION',
			'PF_VALIDATION_CHARACTERS_REQUIRED',
			'PF_VALIDATION_CHECKBOX_REQUIRED',
			'PF_VALIDATION_BOTH_DATE_RANGE_FIELD_REQUIRED',
			'PF_VALIDATION_FIELD_MUST_EQUAL_TEST',
			'PF_VALIDATION_INVALID',
			'PF_VALIDATION_DATE_TIME_RANGE',
			'PF_VALIDATION_MINIMUM',
			'PF_VALIDATION_CHACTERS_ALLOWED',
			'PF_VALIDATION_GROUP_REQUIRED',
			'PF_VALIDATION_MIN',
			'PF_VALIDATION_MAX',
			'PF_VALIDATION_DATE_PRIOR_TO',
			'PF_VALIDATION_DATE_PAST',
			'PF_VALIDATION_MAXIMUM',
			'PF_VALIDATION_OPTION_ALLOW',
			'PF_VALIDATION_PLEASE_SELECT',
			'PF_VALIDATION_FIELDS_DO_NOT_MATCH',
			'PF_VALIDATION_INVALID_CREDIT_CARD_NUMBER',
			'PF_VALIDATION_INVALID_PHONE_NUMBER',
			'PF_VALIDATION_INVALID_EMAIL_ADDRESS',
			'PF_VALIDATION_NOT_A_VALID_INTEGER',
			'PF_VALIDATION_INVALID_FLOATING_DECIMAL_NUMBER',
			'PF_VALIDATION_INVALID_DATE',
			'PF_VALIDATION_INVALID_URL',
			'PF_VALIDATION_NUMBER_ONLY',
			'PF_VALIDATION_LETTERS_ONLY',
			'PF_VALIDATION_NO_SPECIAL_CHACTERS_ALLOWED',
			'PF_VALIDATION_INVALID_USERNAME',
			'PF_VALIDATION_INVALID_EMAIL',
			'PF_VALIDATION_INVALID_PASSWORD',
			'PF_VALIDATION_INVALID_DATE',
			'PF_VALIDATION_EXPECTED_FORMAT',
		];

		foreach ($languageItems as $item)
		{
			Text::script($item, true);
		}

		$loaded = true;
	}
}