<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

namespace OSSolution\PaymentForm\Site\Model;

use JDatabaseQuery;
use Joomla\CMS\Factory;
use OSL\Model\ListModel;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;

defined('_JEXEC') or die;

class Forms extends ListModel
{
	protected function buildQueryColumns(JDatabaseQuery $query)
	{
		parent::buildQueryColumns($query);

		if ($fieldSuffix = PMFormHelper::getFieldSuffix())
		{
			$query->select($this->getDbo()->quoteName('tbl.title' . $fieldSuffix, 'title'));
		}

		return $this;
	}

	/**
	 * Builds a WHERE clause for the query
	 *
	 * @param   JDatabaseQuery  $query
	 *
	 * @return $this
	 */
	protected function buildQueryWhere(JDatabaseQuery $query)
	{
		$now = $this->db->quote($this->getServerTimeFromGMTTime());

		$query->where('tbl.published = 1')
			->where('(tbl.publish_up = "0000-00-00 00:00:00" OR tbl.publish_up <= ' . $now . ')')
			->where('(tbl.publish_down = "0000-00-00 00:00:00" OR tbl.publish_down >= ' . $now . ')')
			->where('tbl.access IN (' . implode(',', $this->container->user->getAuthorisedViewLevels()) . ')');

		return $this;
	}

	/**
	 * Method to get server time from GMT time
	 *
	 * @param   string  $time
	 * @param   string  $format
	 *
	 * @return string
	 */
	protected function getServerTimeFromGMTTime($time = 'now', $format = 'Y-m-d H:i:s')
	{
		$gmtTz  = new \DateTimeZone('GMT');
		$userTz = new \DateTimeZone(Factory::getApplication()->get('offset', 'GMT'));
		$date   = new \DateTime($time, $gmtTz);
		$date->setTimezone($userTz);

		return $date->format($format);
	}
} 