<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

namespace OSSolution\PaymentForm\Site\View\Complete;

use Joomla\CMS\Filter\InputFilter;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use OSL\Utils\Database as DatabaseUtils;
use OSL\View\HtmlView;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;
use PMFormHelperBootstrap;

defined('_JEXEC') or die;

class Html extends HtmlView
{
	public $hasModel = false;

	public function display()
	{
		$app         = $this->container->app;
		$db          = $this->container->db;
		$config      = PMFormHelper::getConfig();
		$fieldSuffix = PMFormHelper::getFieldSuffix();

		$id = (int) $this->container->session->get('pmf_payment_id', 0);

		if (!$id && $orderNumber = $this->input->getString('order_number'))
		{
			$query = $db->getQuery(true)
				->select('id')
				->from('#__pf_payments')
				->where('order_number = ' . $db->quote($orderNumber))
				->order('id DESC');
			$db->setQuery($query);
			$id = (int) $db->loadResult();
		}

		$row = $this->container->factory->createTable('Payment', $db);
		$row->load($id);

		// Wait up to 12 seconds for payment gateway to notify the system about the payment if status of the registration record is still Pending
		if ($row->gross_amount > 0 && $row->published == 0 && strpos($row->payment_method, 'os_offline') === false)
		{
			for ($i = 0; $i < 4; $i++)
			{
				sleep(3);

				// Reload the payment record from database to get updated data
				$row->load($id);

				if ($row->published == 1)
				{
					break;
				}
			}
		}


		if ($row->published == 0 && (in_array($row->payment_method, ['os_ideal', 'os_payu'])))
		{
			// Use online payment method and the payment is not success for some reason, we need to redirect to failure page
			$failureUrl = Route::_('index.php?option=com_pmform&view=cancel&id=' . $row->id . '&Itemid=' . $this->Itemid, false);
			$app->redirect($failureUrl);
		}

		if ($row->id)
		{
			$query = $db->getQuery(true);
			$query->select('*')
				->from('#__pf_forms')
				->where('id = ' . $row->form_id);

			if ($fieldSuffix)
			{
				DatabaseUtils::getMultilingualFields($query, ['title'], $fieldSuffix);
			}

			$db->setQuery($query);
			$form = $db->loadObject();

			if ($form->payment_complete_url)
			{
				$app->redirect($form->payment_complete_url);
			}


			if ($fieldSuffix)
			{
				$keys = ['thanks_message_offline', 'thanks_message'];
				PMFormHelper::prepareMultilingualMessages($form, $keys, $fieldSuffix);
				PMFormHelper::prepareMultilingualMessages($config, $keys, $fieldSuffix);
			}

			if (strpos($row->payment_method, 'os_offline') !== false || ($row->payment_method == 'os_mobilpay' && $row->published == 0))
			{
				$prefix = str_replace('os_offline', '', $row->payment_method);

				if (PMFormHelper::isValidMessage($form->thanks_message_offline))
				{
					$message = $form->thanks_message_offline;
				}
				elseif ($prefix && !empty($config->{'thanks_message_offline' . $prefix}))
				{
					$message = $config->{'thanks_message_offline' . $prefix};
				}
				else
				{
					$message = $config->thanks_message_offline;
				}
			}
			else
			{
				if (PMFormHelper::isValidMessage($form->thanks_message))
				{
					$message = $form->thanks_message;
				}
				else
				{
					$message = $config->thanks_message;;
				}
			}

			$replaces = PMFormHelper::callOverridableHelperMethod('Helper', 'buildReplaceTags', [$row, $config]);

			foreach ($replaces as $key => $value)
			{
				$key     = strtoupper($key);
				$message = str_replace("[$key]", $value, $message);
			}

			$active = $this->container->app->getMenu()->getActive();

			if ($active)
			{
				$params = PMFormHelper::getViewParams($active, 'complete');
				$this->setDocumentMetadata($params);
			}

			$message = PMFormHelper::processConditionalText($message);

			// Support tracking code
			$trackingCode = '';

			if ($row->published == 1 && $row->gross_amount > 0)
			{
				if (!empty($form->tracking_code))
				{
					$trackingCode = $form->tracking_code;
				}
				else
				{
					$trackingCode = $config->tracking_code;
				}

				$filterInput = InputFilter::getInstance();

				$replaces['amount']                 = $filterInput->clean($replaces['amount'], 'float');
				$replaces['discount_amount']        = $filterInput->clean($replaces['discount_amount'], 'float');
				$replaces['tax_amount']             = $filterInput->clean($replaces['tax_amount'], 'float');
				$replaces['gross_amount']           = $filterInput->clean($replaces['gross_amount'], 'float');
				$replaces['payment_processing_fee'] = $filterInput->clean($replaces['payment_processing_fee'], 'float');

				foreach ($replaces as $key => $value)
				{
					$key          = strtoupper($key);
					$trackingCode = str_replace("[$key]", $value, $trackingCode);
				}
			}

			$this->row             = $row;
			$this->message         = $message;
			$this->bootstrapHelper = PMFormHelperBootstrap::getInstance();
			$this->replaces        = $replaces;
			$this->trackingCode    = $trackingCode;

			$this->setLayout('default');

			parent::display();
		}
		else
		{
			$app->enqueueMessage(Text::_('Invalid Payment Record ID'), 'warning');
			//$app->redirect('index.php');
		}
	}
}