<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

$headerText   = Text::_('PF_CONFIRMATION');
$headerText   = str_replace('[FORM_TITLE]', $this->rowForm->title, $headerText);
$goBackAction = base64_decode($this->formPageUrl);

?>
<h1 class="title"><?php echo $headerText; ?></h1>
<?php
$message = $this->config->confirmation_message ;

if ($message)
{
	$message = str_replace('[FORM_TITLE]', $this->rowForm->title, $message) ;
	$message = str_replace('[AMOUNT]', PMFormHelper::formatAmount($this->fees['gross_amount'], $this->config), $message) ;
?>
	<p class="info"><?php echo $message ; ?></p>
<?php
}

if ($this->config->use_https)
{
	$url = Route::_('index.php?option=com_pmform&task=controller.process_payment&Itemid='.$this->Itemid, false, 1);
}
else
{
	$url = Route::_('index.php?option=com_pmform&task=controller.process_payment&Itemid='.$this->Itemid, false);
}

/* @var $bootstrapHelper PMFormHelperBootstrap */
$bootstrapHelper     = $this->bootstrapHelper;
$formHorizontalClass = $bootstrapHelper->getClassMapping('form form-horizontal');
$rowFluidClass       = $bootstrapHelper->getClassMapping('row-fluid');
$controlGroupClass   = $bootstrapHelper->getClassMapping('control-group');
$controlLabelClass   = $bootstrapHelper->getClassMapping('control-label');
$controlsClass       = $bootstrapHelper->getClassMapping('controls');
$btnClass            = $bootstrapHelper->getClassMapping('btn');
$btnPrimaryClass     = $bootstrapHelper->getClassMapping('btn btn-primary');
?>
<form method="post" name="adminForm" id="adminForm" action="<?php echo $url; ?>" class="<?php echo $formHorizontalClass; ?>">
	<?php
	if ($this->couponCode)
	{
	?>
	<div class="<?php echo $controlGroupClass; ?>">
		<div class="<?php echo $controlLabelClass; ?>">
			<?php echo Text::_('PF_COUPON'); ?>
		</div>
		<div class="<?php echo $controlsClass; ?>">
			<?php echo $this->couponCode ; ?>
		</div>
	</div>
	<?php
	}
	if (!$this->userId && $this->config->user_registration)
	{
	?>
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('PF_USERNAME'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php echo $this->username ; ?>
			</div>
		</div>
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('PF_PASSWORD'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php echo $this->password; ?>
			</div>
		</div>
	<?php
	}

	echo $this->form->getOutput(true, $this->bootstrapHelper);

	if ($this->fees['total_amount'] > 0)
	{
	?>
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('PF_TOTAL_AMOUNT'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php echo PMFormHelper::formatCurrency($this->fees['total_amount'], $this->config); ?>
			</div>
		</div>
		<?php
		if ($this->fees['discount_amount'] > 0 || $this->fees['tax_amount'] > 0 || $this->fees['payment_processing_fee'] > 0)
		{
			if ($this->fees['discount_amount'] > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_COUPON_DISCOUNT'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($this->fees['discount_amount'], $this->config);?>
					</div>
				</div>
			<?php
			}

			if ($this->fees['tax_amount'] > 0)
            {
            ?>
                <div class="<?php echo $controlGroupClass; ?>">
                    <div class="<?php echo $controlLabelClass; ?>">
			            <?php echo Text::_('PF_TAX_AMOUNT'); ?>
                    </div>
                    <div class="<?php echo $controlsClass; ?>">
			            <?php echo PMFormHelper::formatCurrency($this->fees['tax_amount'], $this->config);?>
                    </div>
                </div>
            <?php
            }

			if ($this->fees['payment_processing_fee'] > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_PAYMENT_FEE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($this->fees['payment_processing_fee'], $this->config); ?>
					</div>
				</div>
			<?php
			}
			?>
			<div class="<?php echo $controlGroupClass; ?>">
				<div class="<?php echo $controlLabelClass; ?>">
					<?php echo Text::_('PF_GROSS_AMOUNT'); ?>
				</div>
				<div class="<?php echo $controlsClass; ?>">
					<?php echo PMFormHelper::formatCurrency($this->fees['gross_amount'], $this->config); ?>
				</div>
			</div>
		<?php
		}
	}

	if ($this->fees['total_amount'] > 0 || $this->fees['gross_amount'] > 0)
	{
		$method = os_payments::getPaymentMethod($this->paymentMethod);

		if ($method)
		{
		?>
			<div class="<?php echo $controlGroupClass; ?>">
				<div class="<?php echo $controlLabelClass; ?>">
					<?php echo Text::_('PF_PAYMENT_OPTION'); ?>
				</div>
				<div class="<?php echo $controlsClass; ?>">
					<?php echo Text::_($method->getTitle()); ?>
				</div>
			</div>
			<?php
			if ($method->getCreditCard() && $this->x_card_num)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>"><?php echo Text::_('AUTH_CARD_NUMBER'); ?></div>
					<div class="<?php echo $controlsClass; ?>">
						<?php
						$len = strlen($this->x_card_num);
						$remaining = substr($this->x_card_num, $len - 4, 4);
						echo str_pad($remaining, $len, '*', STR_PAD_LEFT);
						?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('AUTH_CARD_EXPIRY_DATE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->expMonth . '/' . $this->expYear; ?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('AUTH_CVV_CODE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_card_code; ?>
					</div>
				</div>
				<?php
				if ($method->getCardType())
				{
				?>
					<div class="<?php echo $controlGroupClass; ?>">
						<div class="<?php echo $controlLabelClass; ?>">
							<?php echo Text::_('PF_CARD_TYPE'); ?>
						</div>
						<div class="<?php echo $controlsClass; ?>">
							<?php echo $this->cardType; ?>
						</div>
					</div>
				<?php
				}
				?>
			<?php
			}

			if ($method->getCardHolderName() && $this->cardHolderName)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_CARD_HOLDER_NAME'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->cardHolderName; ?>
					</div>
				</div>
			<?php
			}

			if ($this->paymentMethod == 'os_echeck')
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_BANK_ROUTING_NUMBER'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_bank_aba_code; ?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_BANK_ACCOUNT_NUMBER'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_bank_acct_num; ?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_BANK_ACCOUNT_TYPE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_bank_acct_type; ?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_BANK_NAME'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_bank_name; ?>
					</div>
				</div>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_ACCOUNT_HOLDER_NAME'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo $this->x_bank_acct_name; ?>
					</div>
				</div>
			<?php
			}
		}
		?>
	<?php
	}
	?>
	<div class="form-actions">
		<input type="button" class="<?php echo $btnClass; ?>" name="btnBack" value="<?php echo  Text::_('PF_BACK') ;?>" onclick="goBack();" />
		<input type="submit" class="<?php echo $btnPrimaryClass; ?>" name="btnSubmit" value="<?php echo  Text::_('PF_PROCESS_PAYMENT') ;?>" />
	</div>
    <?php
        Factory::getDocument()->addScriptDeclaration("
            function goBack()
            {
                var form = document.adminForm;
                form.action = '$goBackAction';
                form.submit();
            }   
        ");
    ?>
<!--  Hidden fields -->
<input type="hidden" name="coupon_code" value="<?php echo $this->couponCode ; ?>" />
<input type="hidden" name="payment_method" value="<?php echo $this->paymentMethod; ?>" />
<input type="hidden" name="x_card_num" value="<?php echo $this->x_card_num; ?>" />
<input type="hidden" name="exp_month" value="<?php echo $this->expMonth; ?>" />
<input type="hidden" name="exp_year" value="<?php echo $this->expYear; ?>" />
<input type="hidden" name="x_exp_date" value="<?php echo $this->x_exp_date ; ?>" />
<input type="hidden" name="x_card_code" value="<?php echo $this->x_card_code; ?>" />
<input type="hidden" name="form_id" value="<?php echo $this->rowForm->id; ?>" />
<input type="hidden" name="card_holder_name" value="<?php echo $this->cardHolderName ; ?>" />

<input type="hidden" name="card_type" value="<?php echo $this->cardType; ?>" />
<input type="hidden" name="bank_id" value="<?php echo $this->bankId ; ?>" />
<input type="hidden" name="form_page_url" value="<?php echo $this->formPageUrl; ?>" />

<?php
if(!empty($this->stripeToken))
{
?>
    <input type="hidden" name="stripeToken" value="<?php echo $this->stripeToken; ?>" />
<?php
}

if (!empty($_POST['nonce']))
{
?>
<input type="hidden" name="nonce" value="<?php echo $_POST['nonce']; ?>" />
<?php
}

if (!$this->userId && $this->config->user_registration)
{
?>
	<input type="hidden" name="username" value="<?php echo $this->username ; ?>" />
	<input type="hidden" name="password1" value="<?php echo $this->password ; ?>" />
<?php
}
	echo $this->hiddenInput;
    echo JHTML::_( 'form.token' );
?>
</form>