<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

namespace OSSolution\PaymentForm\Site\View\Form;

use Joomla\CMS\Captcha\Captcha;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use OSL\Utils\Database as DatabaseUtils;
use OSL\View\HtmlView;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;
use OSSolution\PaymentForm\Site\Helper\PaymentMethods as PaymentMethodsHelper;
use PMFormHelperBootstrap;

defined('_JEXEC') or die;

class Html extends HtmlView
{
	/**
	 * Tell the controller that we don't need a model, so no need to create it
	 *
	 * @var bool
	 */
	public $hasModel = false;

	/**
	 * Display the form
	 */

	public function display()
	{
		$app    = $this->container->app;
		$user   = $this->container->user;
		$input  = $this->input;
		$db     = $this->container->db;
		$query  = $db->getQuery(true);
		$config = PMFormHelper::getConfig();
		$userId = $user->get('id');
		$formId = $input->getInt('form_id', 0);
		$active = $app->getMenu()->getActive();

		if (!$formId)
		{
			$app->enqueueMessage(Text::_('PMF_INVALID_FORM'), 'error');
			$app->redirect(Uri::root(), 404);
		}

		$currentDate = HTMLHelper::_('date', 'now', 'Y-m-d');
		$fieldSuffix = PMFormHelper::getFieldSuffix();

		$query->select('*, DATEDIFF("' . $currentDate . '", late_payment_date) AS number_days')
			->from('#__pf_forms')
			->where('id = ' . $formId);

		if ($fieldSuffix)
		{
			DatabaseUtils::getMultilingualFields($query, ['title'], $fieldSuffix);
		}

		$db->setQuery($query);
		$rowForm = $db->loadObject();

		if (!$rowForm || $rowForm->published == 0)
		{
			$app->enqueueMessage(Text::_('PMF_INVALID_FORM'), 'error');
			$app->redirect(Uri::root(), 404);
		}

		// Check access level of the form
		if (!in_array($rowForm->access, $user->getAuthorisedViewLevels()))
		{
			if (!$user->id)
			{
				$returnUrl = Uri::getInstance()->toString();
				$url       = Route::_('index.php?option=com_users&view=login&return=' . base64_encode($returnUrl), false);
				$msg       = Text::_('PMF_LOGIN_TO_ACCESS_TO_FORM');
				$app->enqueueMessage(Text::_($msg));
				$app->redirect($url);
			}
			else
			{
				$app->enqueueMessage(Text::_('PMF_NOT_ALLOWED_TO_ACCESS_FORM'), 'error');
				$app->redirect(Uri::root(), 403);
			}
		}

		// Pass user registration setting from form to configuration

		if ((int) $rowForm->user_registration !== 2)
		{
			$config->user_registration = $rowForm->user_registration;
		}

		if ((int) $rowForm->show_login_box !== 2)
		{
			$config->show_login_box = $rowForm->show_login_box;
		}

		$rowFields      = PMFormHelper::getFormFields($formId, $fieldSuffix);
		$captchaInvalid = $this->container->session->get('pf_captcha_invalid');

		if ($captchaInvalid)
		{
			$data = $input->post->getData();
		}
		else
		{
			// Try to get data from session
			$data = $app->getUserState('com_pmform.formdata', null);

			if ($data)
			{
				$data = unserialize($data);
			}
			else
			{
				$data = PMFormHelper::getFormData($rowFields, $userId, $config);

				if (!count($data))
				{
					$data = $input->getData();
				}
			}
		}

		if ($userId && !isset($data['first_name']))
		{
			//Load the name from Joomla user data
			$name = $user->name;

			if ($name)
			{
				$pos = strpos($name, ' ');

				if ($pos !== false)
				{
					$data['first_name'] = substr($name, 0, $pos);
					$data['last_name']  = substr($name, $pos + 1);
				}
				else
				{
					$data['first_name'] = $name;
					$data['last_name']  = '';
				}
			}
		}

		if ($userId && !isset($data['email']))
		{
			$data['email'] = $user->email;
		}

		if (!isset($data['country']) || !$data['country'])
		{
			$data['country'] = $config->default_country;
		}

		foreach ($rowFields as $rowField)
		{
			if ($rowField->populate_from_previous_payment)
			{
				continue;
			}

			unset($data[$rowField->name]);
		}

		reset($rowFields);

		$data = $data + $_GET;

		//Get data
		$form = new \POSFForm($rowFields);

		if ($captchaInvalid)
		{
			$useDefault = false;
		}
		else
		{
			$useDefault = true;
		}

		$form->bind($data, $useDefault);
		$form->prepareFormField();
		$form->buildFieldsDependency();


		$options            = [];
		$options[]          = HTMLHelper::_('select.option', 'Visa', 'Visa');
		$options[]          = HTMLHelper::_('select.option', 'MasterCard', 'MasterCard');
		$options[]          = HTMLHelper::_('select.option', 'Discover', 'Discover');
		$options[]          = HTMLHelper::_('select.option', 'Amex', 'American Express');
		$lists['card_type'] = HTMLHelper::_('select.genericlist', $options, 'card_type', ' class="form-select" ', 'value', 'text');

		//Expiration month, expiration year
		$lists['exp_month'] = HTMLHelper::_('select.integerlist', 1, 12, 1, 'exp_month', ' class="input-small form-select d-inline-block w-auto" ', $input->getInt('exp_month', date('m')), '%02d');
		$currentYear        = date('Y');
		$lists['exp_year']  = HTMLHelper::_('select.integerlist', $currentYear, $currentYear + 10, 1, 'exp_year', 'class="input-small form-select d-inline-block w-auto"', $input->getInt('exp_year', date('Y')));

		if ($config->enable_payment_method_selection && $rowForm->payment_methods && strpos('0', $rowForm->payment_methods) === false)
		{
			$methods       = PaymentMethodsHelper::getPaymentMethods($rowForm->payment_methods);
			$paymentMethod = $input->getString('payment_method', PaymentMethodsHelper::getDefaultPaymentMethod($rowForm->payment_methods));
		}
		else
		{
			$methods       = PaymentMethodsHelper::getPaymentMethods();
			$paymentMethod = $input->getString('payment_method', PaymentMethodsHelper::getDefaultPaymentMethod());
		}

		$method = PaymentMethodsHelper::getPaymentMethod($paymentMethod);
		$fees   = PMFormHelper::callOverridableHelperMethod('Helper', 'calculateFormFee', [$rowForm, $form, $input, $paymentMethod]);

		// Prepare form message
		if ($fieldSuffix)
		{
			PMFormHelper::prepareMultilingualMessages($rowForm, ['form_msg'], $fieldSuffix);
			PMFormHelper::prepareMultilingualMessages($config, ['donation_form_msg'], $fieldSuffix);
		}

		if (PMFormHelper::isValidMessage($rowForm->form_msg))
		{
			$config->donation_form_msg = $rowForm->form_msg;
		}

		if ($active && $active->component == 'com_pmform'
			&& isset($active->query['view'], $active->query['layout'])
			&& $active->query['view'] == 'form' && $active->query['layout'])
		{
			$this->setLayout($active->query['layout']);
		}
		elseif ($rowForm->form_layout && file_exists(JPATH_ROOT . '/components/com_pmform/View/Form/tmpl/' . $rowForm->form_layout . '.php'))
		{
			$this->setLayout($rowForm->form_layout);
		}

		// Captcha integration
		$showCaptcha = 0;

		if ($config->enable_captcha)
		{
			$captchaPlugin = $app->getParams()->get('captcha', $this->container->appConfig->get('captcha'));

			if (!$captchaPlugin)
			{
				// Hardcode to recaptcha, reduce support request
				$captchaPlugin = 'recaptcha';
			}

			$plugin = PluginHelper::getPlugin('captcha', $captchaPlugin);

			if ($plugin)
			{
				$showCaptcha         = 1;
				$this->captcha       = Captcha::getInstance($captchaPlugin)->display('dynamic_recaptcha_1', 'dynamic_recaptcha_1', 'required');
				$this->captchaPlugin = $captchaPlugin;
			}
			else
			{
				$app->enqueueMessage(Text::_('PF_CAPTCHA_NOT_ACTIVATED_IN_YOUR_SITE'), 'error');
			}
		}

		// Show payment fee
		$showPaymentFee = false;

		foreach ($methods as $method)
		{
			if ($method->paymentFee)
			{
				$showPaymentFee = true;
				break;
			}
		}

		$active = $this->container->app->getMenu()->getActive();

		if ($active && !$this->input->getInt('hmvc', 0))
		{
			$params = PMFormHelper::getViewParams($active, 'form');
			$this->setDocumentMetadata($params);
		}

		// Override currency symbol from form
		if ($rowForm->currency_symbol)
		{
			$config->currency_symbol = $rowForm->currency_symbol;
		}

		// Assign these parameters
		$this->form                 = $form;
		$this->userId               = $userId;
		$this->paymentMethod        = $paymentMethod;
		$this->lists                = $lists;
		$this->config               = $config;
		$this->methods              = $methods;
		$this->method               = $method;
		$this->captchaInvalid       = $captchaInvalid;
		$this->showCaptcha          = $showCaptcha;
		$this->formPageUrl          = base64_encode(Uri::getInstance()->toString());
		$this->rowForm              = $rowForm;
		$this->totalAmount          = $fees['total_amount'];
		$this->discountAmount       = $fees['discount_amount'];
		$this->taxAmount            = $fees['tax_amount'];
		$this->grossAmount          = $fees['gross_amount'];
		$this->paymentProcessingFee = $fees['payment_processing_fee'];
		$this->showPaymentFee       = $showPaymentFee;

		// Disable ajax email validation if needed
		if ($this->userId || !$this->config->user_registration)
		{
			$this->preprocessFormFields();
		}

		$this->bootstrapHelper = PMFormHelperBootstrap::getInstance();

		parent::display();
	}

	/**
	 * Pre-process form fields
	 *
	 * @param   \POSFForm  $form
	 */
	protected function preprocessFormFields()
	{
		$fields = $this->form->getFields();

		if (!isset($fields['email']))
		{
			return;
		}

		/* @var \POSFFormField $field */
		$field = $fields['email'];

		$cssClass = $field->getAttribute('class');
		$cssClass = str_replace(',ajax[ajaxEmailCall]', '', $cssClass);
		$field->setAttribute('class', $cssClass);
		$this->form->setFields($fields);
	}
}