<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use OSSolution\PaymentForm\Site\Helper\PaymentMethods as PaymentMethodsHelper;

defined('_JEXEC') or die ;

HTMLHelper::_('behavior.core');
HTMLHelper::_('behavior.keepalive');

$headerText = Text::_('PF_FORM_FOR') ;
$headerText = str_replace('[FORM_TITLE]', $this->rowForm->title, $headerText) ;
$message = $this->config->donation_form_msg;
$message = str_replace('[FORM_TITLE]', $this->rowForm->title, $message) ;
$message = str_replace('[AMOUNT]', number_format($this->grossAmount, 2), $message) ;

if ($this->config->use_https)
{
	$url = Route::_('index.php?option=com_pmform&Itemid='.$this->Itemid, false, 1);
}
else
{
	$url = Route::_('index.php?option=com_pmform&Itemid='.$this->Itemid, false);
}

PMFormHelperJquery::validateForm();
$selectedState = '';

/* @var $bootstrapHelper PMFormHelperBootstrap */
$bootstrapHelper     = $this->bootstrapHelper;
$formHorizontalClass = $bootstrapHelper->getClassMapping('form form-horizontal');
$rowFluidClass       = $bootstrapHelper->getClassMapping('row-fluid');
$controlGroupClass   = $bootstrapHelper->getClassMapping('control-group');
$controlLabelClass   = $bootstrapHelper->getClassMapping('control-label');
$controlsClass       = $bootstrapHelper->getClassMapping('controls');
$btnClass            = $bootstrapHelper->getClassMapping('btn');
$btnPrimaryClass     = $bootstrapHelper->getClassMapping('btn btn-primary');
$clearFixClass       = $bootstrapHelper->getClassMapping('clearfix');
$span6Class          = $bootstrapHelper->getClassMapping('span6');
?>
<div id="pmform-form" class="<?php echo $rowFluidClass; ?> pf-container">
	<h1 class="title"><?php echo $headerText; ?></h1>
	<?php
	if (strlen($message))
	{
	?>
		<div class="pf-message"><?php echo $message; ?></div>
	<?php
	}

	if (!$this->userId && $this->config->user_registration && $this->config->show_login_box)
	{
		$validateLoginForm = 1;
		echo $this->loadCommonLayout('form_login');
	}
	else
	{
		$validateLoginForm = 0;
	}
	?>
	<form method="post" name="os_form" id="os_form" action="<?php echo $url ; ?>"<?php if (!$this->config->enable_browser_autocomplete) echo ' autocomplete="off"'; ?> class="form" enctype="multipart/form-data">
		<?php
		    echo $this->loadCommonLayout('form_register');
		?>
		<div class="form-fields-container <?php echo $clearFixClass; ?>">
			<?php
			$fields = $this->form->getFields();

			if (isset($fields['state']))
			{
				$selectedState = $fields['state']->value;
			}

			$i = 0;
			$numberFields = count($fields);

			/* @var POSFFormField $field */
			foreach ($fields as $field)
			{
				if ($i %2  == 0)
				{
				?>
                    <div class="<?php echo $rowFluidClass . ' ' . $clearFixClass; ?>">
				<?php
				}
				?>
				<div class="<?php echo $span6Class; ?>">
					<?php echo $field->getControlGroup(true, $bootstrapHelper); ?>
				</div>
				<?php
                if (($i + 1) % 2 == 0)
				{
				?>
					</div>
				<?php
				}
				?>
				<?php
				$i++;
			}
			if (($i + 1) % 2 == 0)
			{
			?>
		</div>
	<?php
	}
	?>
</div>
<div class="payment-information-container <?php echo $formHorizontalClass . ' ' . $clearFixClass; ?>">
<?php
if (($this->totalAmount > 0) || $this->form->containFeeFields())
{
	$buttonText = Text::_('PF_PROCESS_PAYMENT');
	echo $this->loadCommonLayout('form_payment_amounts');
	echo $this->loadCommonLayout('form_payment_methods');
}
else
{
	$buttonText = Text::_('PF_SUBMIT');
}

if($this->showCaptcha)
{
	if ($this->captchaPlugin == 'recaptcha_invisible')
	{
		$style = ' style="display:none;"';
	}
	else
	{
		$style = '';
	}
	?>
    <div class="<?php echo $controlGroupClass; ?>">
        <div class="<?php echo $controlLabelClass; ?>"<?php echo $style;?>>
			<?php echo Text::_('PF_CAPTCHA'); ?><span class="required">*</span>
        </div>
        <div class="<?php echo $controlsClass; ?>">
			<?php echo $this->captcha; ?>
        </div>
    </div>
	<?php
}

echo $this->loadCommonLayout('form_terms_and_conditions');

if ($this->config->show_confirmation_step)
{
	$task = 'payment_confirmation';
	$buttonText = Text::_('PF_PAYMENT_CONFIRMATION');
}
else
{
	$task = 'controller.process_payment';
}
?>
<div class="form-actions">
	<input type="submit" id="btn-submit" class="<?php echo $btnPrimaryClass; ?>" name="btnSubmit" value="<?php echo $buttonText;?>" />
	<img id="ajax-loading-animation" src="<?php echo Uri::base(true);?>/media/com_pmform/assets/icons/ajax-loadding-animation.gif" style="display: none;"/>
</div>
<?php
if (count($this->methods) == 1)
{
?>
	<input type="hidden" name="payment_method" value="<?php echo $this->methods[0]->getName(); ?>" />
<?php
}

if ($this->grossAmount == 0)
{
	$hidePaymentInformation = true;
}
else
{
	$hidePaymentInformation = false;
}

PaymentMethodsHelper::writeJavascriptObjects();

$rootUri = Uri::root(true);

Factory::getDocument()->addScriptOptions('selectedState', $selectedState)
	->addScriptOptions('hidePaymentInformation', $hidePaymentInformation)
	->addScript($rootUri . '/media/com_pmform/assets/js/paymentform.min.js')
	->addScript(Uri::root(true) . '/media/com_pmform/js/site-form-default.min.js')
	->addScriptDeclaration('var siteUrl = "' . $rootUri . '/";');
?>
<input type="hidden" name="count_method" value="<?php echo count($this->methods); ?>" />
<input type="hidden" name="form_page_url" value="<?php echo $this->formPageUrl; ?>" />
<input type="hidden" name="form_id" value="<?php echo $this->rowForm->id; ?>" />
<input type="hidden" name="task" value="<?php echo $task; ?>" />
<input type="hidden" name="show_payment_fee" value="<?php echo (int)$this->showPaymentFee ; ?>" />
<input type="hidden" id="card-nonce" name="nonce" />
<?php echo HTMLHelper::_( 'form.token' ); ?>
</div>
</form>
</div>