<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

namespace OSSolution\PaymentForm\Site\View\History;

use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use OSL\Utils\Database as DatabaseUtils;
use OSL\View\HtmlView;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;
use PMFormHelperBootstrap;

defined('_JEXEC') or die;

class Html extends HtmlView
{
	/**
	 * @var bool Indicate that this view doesn't have a model, so controller don't need to create it.
	 */
	public $hasModel = false;

	/**
	 * Method to display the view
	 *
	 */
	public function display()
	{
		$user = $this->container->user;

		if (!$user->id)
		{
			//Redirect user, ask them for login
			$return = base64_encode(Route::_('index.php?option=com_pmform&view=history&Itemid=' . $this->Itemid, false));

			$this->container->app->enqueueMessage(Text::_('PF_LOGIN_TO_ACCESS_PAYMENT_HISTORY'));
			$this->container->app->redirect(Route::_('index.php?option=com_users&view=login&return=' . $return, false));
		}

		/* @var \OSSolution\PaymentForm\Admin\Model\Payments $model */
		$model = $this->container->factory->createModel('Payments', ['ignore_request' => true, 'table_prefix' => '#__pf_'], 'admin');

		$model->setState('filter_order', 'created_date')
			->setState('filter_order_Dir', 'DESC')
			->setState('filter_user_id', $user->id);

		$active = $this->container->app->getMenu()->getActive();

		if ($active)
		{
			$params = PMFormHelper::getViewParams($active, 'history');
			$this->setDocumentMetadata($params);
		}

		$fieldSuffix = PMFormHelper::getFieldSuffix();

		// Get list of fields which are configured to be show
		$db    = $model->getDbo();
		$query = $db->getQuery(true);
		$query->select('*')
			->from('#__pf_fields')
			->where('published = 1')
			->where('show_on_payments_list = 1')
			->order('ordering');

		if ($fieldSuffix)
		{
			DatabaseUtils::getMultilingualFields($query, ['title'], $fieldSuffix);
		}

		$db->setQuery($query);
		$fields = $db->loadObjectList();

		$noneCoreFieldIds = [];

		foreach ($fields as $field)
		{
			if (!$field->is_core)
			{
				$noneCoreFieldIds[] = $field->id;
			}
		}

		$this->items           = $model->getData();
		$this->pagination      = $model->getPagination();
		$this->fields          = $fields;
		$this->fieldsData      = $model->getFieldsData($noneCoreFieldIds);
		$this->config          = PMFormHelper::getConfig();
		$this->bootstrapHelper = PMFormHelperBootstrap::getInstance();

		parent::display();
	}
}