<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die ;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use OSSolution\PaymentForm\Site\Helper\Helper as PMFormHelper;

$colSpan          = 4;
$rowFluidClass    = $this->bootstrapHelper->getClassMapping('row-fluid');
$hiddenPhoneClass = $this->bootstrapHelper->getClassMapping('hidden-phone');
?>
<div id="payment-history-page" class="<?php echo $rowFluidClass; ?> pf-container">
<h1 class="title"><?php echo Text::_('PF_PAYMENT_HISTORY') ; ?></h1>
<table class="<?php echo $this->bootstrapHelper->getClassMapping('table table-striped table-bordered'); ?> table-condensed">
	<thead>
		<tr>
			<th>
				<?php echo Text::_('PF_FORM') ?>
			</th>
            <?php
                foreach ($this->fields as $field)
                {
                    $colSpan++;
                ?>
                    <th>
                        <?php echo $field->title; ?>
                    </th>
                <?php
                }
            ?>
			<th class="center <?php echo $hiddenPhoneClass; ?>">
				<?php echo Text::_('PF_PAYMENT_DATE') ; ?>
			</th>
			<th align="right">
				<?php echo Text::_('PF_AMOUNT') ; ?>
			</th>
			<th class="<?php echo $hiddenPhoneClass; ?>">
				<?php echo Text::_('PF_TRANSACTION_ID') ; ?>
			</th>
			<?php
			if ($this->config->activate_invoice_feature)
			{
			    $colSpan++;
			?>
				<th class="<?php echo $hiddenPhoneClass; ?>">
					<?php echo Text::_('PF_INVOICE_NUMBER') ; ?>
				</th>
			<?php
			}
			?>
		</tr>
	</thead>
	<tbody>
	<?php
		for ($i = 0 , $n = count($this->items) ; $i < $n ; $i++)
		{
			$row = $this->items[$i] ;
		?>
			<tr>
				<td>
					<?php echo $row->title; ?>
				</td>
                <?php
                    foreach ($this->fields as $field)
                    {
                        if ($field->is_core)
                        {
                            $fieldValue = $row->{$field->name};
                        }
                        elseif (isset($this->fieldsData[$row->id][$field->id]))
                        {
	                        $fieldValue = $this->fieldsData[$row->id][$field->id];
                        }
                        else
                        {
                            $fieldValue = '';
                        }
                    ?>
                        <td><?php echo $fieldValue; ?></td>
                    <?php
                    }
                ?>
				<td class="center <?php echo $hiddenPhoneClass; ?>">
					<?php echo HTMLHelper::_('date', $row->payment_date ?: $row->created_date, $this->config->date_format) ; ?>
				</td>
				<td class="text-right">
					<?php echo PmFormHelper::formatAmount($row->gross_amount, $this->config) ; ?>
				</td>
				<td class="center <?php echo $hiddenPhoneClass; ?>">
					<?php echo $row->transaction_id ; ?>
				</td>
				<?php
					if ($this->config->activate_invoice_feature)
					{
					?>
					<td>
						<a href="<?php echo Route::_('index.php?option=com_pmform&task=download_invoice&id='.$row->id); ?>" title="<?php echo Text::_('PM_DOWNLOAD'); ?>"><?php echo PMFormHelper::formatInvoiceNumber($row->invoice_number, $this->config) ; ?></a>
					</td>
					<?php
					}
				?>
			</tr>
		<?php
		}
	?>
	</tbody>
	<?php
		if ($this->pagination->total > $this->pagination->limit)
		{
		?>
			<tfoot>
				<tr>
					<td colspan="<?php echo $colSpan; ?>">
						<div class="pagination"><?php echo $this->pagination->getListFooter(); ?></div>
					</td>
				</tr>
			</tfoot>
		<?php
		}
	?>
</table>
</div>