<?php
/**
 * @version        6.2.0
 * @package        Joomla
 * @subpackage     Payment Form
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2010 - 2021 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

use Joomla\CMS\Language\Text;
use OSSolution\PaymentForm\Site\Helper\PaymentMethods as PaymentMethodsHelper;

// no direct access
defined('_JEXEC') or die;

$bootstrapHelper     = PMFormHelperBootstrap::getInstance();
$formHorizontalClass = $bootstrapHelper->getClassMapping('form form-horizontal');
$controlGroupClass   = $bootstrapHelper->getClassMapping('control-group');
$controlLabelClass   = $bootstrapHelper->getClassMapping('control-label');
$controlsClass       = $bootstrapHelper->getClassMapping('controls');
?>
<form id="adminForm" class="<?php echo $formHorizontalClass; ?>">
	<div class="<?php echo $controlGroupClass; ?>">
		<div class="<?php echo $controlLabelClass; ?>">
			<?php echo Text::_('PF_FORM'); ?>
		</div>
		<div class="<?php echo $controlsClass; ?>">
			<?php echo $formTitle; ?>
		</div>
	</div>
	<?php
	if (isset($couponCode))
	{
	?>
	<div class="<?php echo $controlGroupClass; ?>">
		<div class="<?php echo $controlLabelClass; ?>">
			<?php echo Text::_('PF_COUPON'); ?>
		</div>
		<div class="<?php echo $controlsClass; ?>">
			<?php echo $couponCode; ?>
		</div>
	</div>
	<?php
	}

	if ($enterAmount && $row->amount == $row->total_amount)
	{
		$form->removeField('amount');
	}

	$fields = $form->getFields();

	foreach ($fields as $field)
	{
		if (!$field->row->show_on_email)
		{
			continue;
		}

		echo $field->getOutput(true, $bootstrapHelper);
	}

	if ($row->total_amount > 0)
	{
	?>
		<div class="<?php echo $controlGroupClass; ?>">
			<div class="<?php echo $controlLabelClass; ?>">
				<?php echo Text::_('PF_TOTAL_AMOUNT'); ?>
			</div>
			<div class="<?php echo $controlsClass; ?>">
				<?php echo PMFormHelper::formatCurrency($row->total_amount, $config); ?>
			</div>
		</div>
		<?php
		if ($row->discount_amount > 0 || $row->tax_amount > 0 || $row->late_fee > 0 || $row->payment_processing_fee > 0)
		{
			if ($row->discount_amount > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_COUPON_DISCOUNT'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($row->discount_amount, $config); ?>
					</div>
				</div>
			<?php
			}

			if ($row->tax_amount > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_TAX_AMOUNT'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($row->tax_amount, $config); ?>
					</div>
				</div>
			<?php
			}

			if ($row->late_fee > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_LATE_FEE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($row->late_fee, $config); ?>
					</div>
				</div>
			<?php
			}

			if ($row->payment_processing_fee > 0)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_PAYMENT_FEE'); ?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo PMFormHelper::formatCurrency($row->payment_processing_fee, $config); ?>
					</div>
				</div>
			<?php
			}
			?>
			<div class="<?php echo $controlGroupClass; ?>">
				<div class="<?php echo $controlLabelClass; ?>">
					<?php echo Text::_('PF_GROSS_AMOUNT'); ?>
				</div>
				<div class="<?php echo $controlsClass; ?>">
					<?php echo PMFormHelper::formatCurrency($row->gross_amount, $config); ?>
				</div>
			</div>
			<?php
		}
		if ($row->total_amount > 0 || $row->gross_amount > 0)
		{
			$method = PaymentMethodsHelper::getPaymentMethod($row->payment_method);
			if ($method)
			{
			?>
				<div class="<?php echo $controlGroupClass; ?>">
					<div class="<?php echo $controlLabelClass; ?>">
						<?php echo Text::_('PF_PAYMENT_OPTION');?>
					</div>
					<div class="<?php echo $controlsClass; ?>">
						<?php echo Text::_($method->getTitle()); ?>
					</div>
				</div>
			<?php
			}
			?>
			<div class="<?php echo $controlGroupClass; ?>">
				<div class="<?php echo $controlLabelClass; ?>">
					<?php echo Text::_('PF_TRANSACTION_ID');?>
				</div>
				<div class="<?php echo $controlsClass; ?>">
					<?php echo $row->transaction_id; ?>
				</div>
			</div>
			<?php
		}
	}
	?>
</form>
