<?php
/**
 * @version            4.3
 * @package            Joomla
 * @subpackage         Payment Form
 * @author             Tuan Pham Ngoc
 * @copyright          Copyright (C) 2010 - 2016 Ossolution Team
 * @license            GNU/GPL, see LICENSE.php
 */
// no direct access
defined('_JEXEC') or die;

class os_stripe extends POSFPaymentOmnipay
{

	protected $omnipayPackage = 'Stripe';

	/**
	 * Constructor
	 *
	 * @param JRegistry $params
	 * @param array     $config
	 */
	public function __construct($params, $config = array('type' => 1))
	{
		$config['params_map'] = array(
			'apiKey' => 'stripe_api_key'
		);

		$document  = JFactory::getDocument();
		$publicKey = $params->get('stripe_public_key');

		if ($params->get('use_stripe_card_element', 0))
		{
			$version = PMFormHelper::getInstalledVersion();

			if (version_compare($version, '5.4.0', 'le'))
			{
				JFactory::getApplication()->enqueueMessage(JText::_('PMF_STRIPE_CARD_ELEMENT_WARNING'), 'warning');
			}

			$document->addScript('https://js.stripe.com/v3/');
			$document->addScriptDeclaration(
				"   var stripe = Stripe('$publicKey');\n
					var elements = stripe.elements();\n
					var stripeCardElement = '';\n
				"
			);

			$config['type'] = 0;
		}
		else
		{
			$document->addScript('https://js.stripe.com/v2/');
			$document->addScriptDeclaration(
				"   var stripePublicKey = '$publicKey';\n
					Stripe.setPublishableKey('$publicKey');\n
				"
			);
		}

		parent::__construct($params, $config);
	}

	/**
	 * Add stripeToken to request message
	 *
	 * @param \Omnipay\Common\Message\AbstractRequest $request
	 * @param JTable                                  $row
	 * @param array                                   $data
	 */
	protected function beforeRequestSend($request, $row, $data)
	{
		parent::beforeRequestSend($request, $row, $data);

		$request->setToken($data['stripeToken']);
	}
}