/****
 * Payme method class
 * @param id
 * @param name
 * @param title
 * @param creditCard
 * @param cardType
 * @param cardCvv
 * @param cardHolderName
 * @return
 */
function PaymentMethod(name, creditCard, cardType, cardCvv, cardHolderName) {
    this.name = name;
    this.creditCard = creditCard;
    this.cardType = cardType;
    this.cardCvv = cardCvv;
    this.cardHolderName = cardHolderName;
}

/***
 * Get name of the payment method
 * @return string
 */
PaymentMethod.prototype.getName = function () {
    return this.name;
};
/***
 * This is creditcard payment method or not
 * @return int
 */
PaymentMethod.prototype.getCreditCard = function () {
    return this.creditCard;
};
/****
 * Show creditcard type or not
 * @return string
 */
PaymentMethod.prototype.getCardType = function () {
    return this.cardType;
};
/***
 * Check to see whether card cvv code is required
 * @return string
 */
PaymentMethod.prototype.getCardCvv = function () {
    return this.cardCvv;
};
/***
 * Check to see whether this payment method require entering card holder name
 * @return
 */
PaymentMethod.prototype.getCardHolderName = function () {
    return this.cardHolderName;
};
/***
 * Get name of the payment method
 * @return string
 */
PaymentMethod.prototype.getEnableRecurring = function () {
    return this.enableRecurring;
};

/***
 * Payment method class, hold all the payment methods
 */
function PaymentMethods() {
    this.length = 0;
    this.methods = [];
}

/***
 * Add a payment method to array
 * @param paymentMethod
 * @return
 */
PaymentMethods.prototype.Add = function (paymentMethod) {
    this.methods[this.length] = paymentMethod;
    this.length = this.length + 1;
};
/***
 * Find a payment method based on it's name
 * @param name
 * @return {@link PaymentMethod}
 */
PaymentMethods.prototype.Find = function (name) {
    for (var i = 0; i < this.length; i++) {
        if (this.methods[i].name == name) {
            return this.methods[i];
        }
    }
    return null;
}

var stripeResponseHandler = function (status, response) {
    PMF.jQuery(function ($) {
        var $form = $('#os_form');
        if (response.error) {
            // Show the errors on the form
            //$form.find('.payment-errors').text(response.error.message);
            alert(response.error.message);
            $form.find('#btn-submit').prop('disabled', false);
        } else {
            // token contains id, last4, and card type
            var token = response.id;
            // Empty card data since we now have token
            $('#x_card_num').val('');
            $('#x_card_code').val('');
            $('#card_holder_name').val('');
            // Insert the token into the form so it gets submitted to the server
            $form.append($('<input type="hidden" name="stripeToken" />').val(token));
            // and re-submit
            $form.get(0).submit();
        }
    });
};

function stripeTokenHandler(token) {
    // Insert the token ID into the form so it gets submitted to the server
    var form = document.getElementById('os_form');
    var hiddenInput = document.createElement('input');
    hiddenInput.setAttribute('type', 'hidden');
    hiddenInput.setAttribute('name', 'stripeToken');
    hiddenInput.setAttribute('value', token.id);
    form.appendChild(hiddenInput);

    // Submit the form
    form.submit();
}

PMF.jQuery(function ($) {
    /**
     * JD validate form
     */
    PMFVALIDATEFORM = (function (formId) {
        $(formId).validationEngine('attach', {
            onValidationComplete: function (form, status) {
                if (status == true) {
                    form.on('submit', function (e) {
                        e.preventDefault();
                    });

                    var paymentMethod;

                    if ($('input:radio[name^=payment_method]').length) {
                        paymentMethod = $('input:radio[name^=payment_method]:checked').val();
                    } else {
                        paymentMethod = $('input[name^=payment_method]').val();
                    }

                    if (typeof stripePublicKey !== 'undefined' && paymentMethod == 'os_stripe' && $('input[name^=x_card_code]').is(':visible')) {
                        Stripe.card.createToken({
                            number: $('input[name^=x_card_num]').val(),
                            cvc: $('input[name^=x_card_code]').val(),
                            exp_month: $('select[name^=exp_month]').val(),
                            exp_year: $('select[name^=exp_year]').val(),
                            name: $('input[name^=card_holder_name]').val()
                        }, stripeResponseHandler);

                        return false;
                    }

                    // Stripe card element
                    if (typeof stripe !== 'undefined' && paymentMethod == 'os_stripe' && $('#stripe-card-form').is(":visible")) {
                        stripe.createToken(stripeCardElement).then(function (result) {
                            if (result.error) {
                                // Inform the customer that there was an error.
                                //var errorElement = document.getElementById('card-errors');
                                //errorElement.textContent = result.error.message;
                                alert(result.error.message);
                            } else {
                                // Send the token to your server.
                                stripeTokenHandler(result.token);
                            }
                        });

                        return false;
                    }

                    if (paymentMethod == 'os_squareup' && $('#tr_card_number').is(':visible')) {
                        sqPaymentForm.requestCardNonce();

                        return false;
                    }

                    return true;
                }

                // In case it is failed, we need to re-enable the button
                $('#btn-submit').removeAttr('disabled');
                $('#ajax-loading-animation').hide();

                return false;
            }
        });
    });

    /***
     * Process event when someone change a payment method
     */
    updatePaymentMethod = (function () {
        var paymentMethod;

        if ($('input:radio[name^=payment_method]').length) {
            paymentMethod = $('input:radio[name^=payment_method]:checked').val();
        } else {
            paymentMethod = $('input[name^=payment_method]').val();
        }

        method = methods.Find(paymentMethod);

        if (method.getCreditCard()) {
            $('#tr_card_number').slideDown();
            $('#tr_exp_date').slideDown();
            $('#tr_cvv_code').slideDown();
            if (method.getCardType()) {
                $('#tr_card_type').slideDown();
            } else {
                $('#tr_card_type').slideUp();
            }
            if (method.getCardHolderName()) {
                $('#tr_card_holder_name').slideDown();
            } else {
                $('#tr_card_holder_name').slideUp();
            }
        } else {
            $('#tr_card_number').slideUp();
            $('#tr_exp_date').slideUp();
            $('#tr_cvv_code').slideUp();
            $('#tr_card_type').slideUp();
            $('#tr_card_holder_name').slideUp();
        }

        if (paymentMethod == 'os_ideal') {
            $('#tr_bank_list').slideDown();
        } else {
            $('#tr_bank_list').slideUp();
        }

        if (paymentMethod == 'os_squareup') {
            $('#sq_field_zipcode').show();
        } else {
            $('#sq_field_zipcode').hide();
        }

        if (typeof stripe !== 'undefined') {
            if (paymentMethod.indexOf('os_stripe') == 0) {
                $('#stripe-card-form').show();
            } else {
                $('#stripe-card-form').hide();
            }
        }
    });

    /***
     * Process event when someone change a payment method
     */
    changePaymentMethod = (function () {
        updatePaymentMethod();
        if ($('input[name^=show_payment_fee]').val() == 1) {
            calculateFormFee();
        }
    });


    calculateFormFee = (function () {
        var paymentMethod;

        $('#btn-submit').attr('disabled', 'disabled');
        $('#ajax-loading-animation').show();
        if ($('input:radio[name^=payment_method]').length) {
            paymentMethod = $('input:radio[name^=payment_method]:checked').val();
        } else {
            paymentMethod = $('input[name^=payment_method]').val();
        }

        var formFieldSelector = '#os_form input[name=\'form_id\'], #os_form input[name=\'coupon_code\'], #os_form .payment-calculation input[type=\'text\'], #os_form .payment-calculation input[type=\'number\'], #os_form .payment-calculation input[type=\'range\'], #os_form .payment-calculation input[type=\'hidden\'], #os_form .payment-calculation input[type=\'checkbox\']:checked, #os_form .payment-calculation input[type=\'radio\']:checked, #os_form .payment-calculation select';

        $.ajax({
            type: 'POST',
            url: siteUrl + 'index.php?option=com_pmform&task=calculate_form_fee&payment_method=' + paymentMethod,
            data: jQuery(formFieldSelector),
            dataType: 'json',
            success: function (msg, textStatus, xhr) {
                $('#btn-submit').removeAttr('disabled');
                $('#ajax-loading-animation').hide();
                if ($('#total_amount')) {
                    $('#total_amount').val(msg.total_amount);
                }
                if ($('#discount_amount')) {
                    $('#discount_amount').val(msg.discount_amount);
                }
                if ($('#tax_amount')) {
                    $('#tax_amount').val(msg.tax_amount);
                }
                if ($('#late_fee')) {
                    $('#late_fee').val(msg.late_fee);
                }
                if ($('#gross_amount')) {
                    $('#gross_amount').val(msg.gross_amount);
                }

                if ($('#payment_processing_fee')) {
                    $('#payment_processing_fee').val(msg.payment_processing_fee);
                }

                if (($('#gross_amount').length || $('#total_amount').length) && msg.gross_amount == 0) {
                    $('.payment_information').css('display', 'none');
                } else {
                    $('.payment_information').css('display', '');
                    updatePaymentMethod();
                }

                if (msg.coupon_valid == 1) {
                    $('#coupon_validate_msg').hide();
                } else {
                    $('#coupon_validate_msg').show();
                }
            },
            error: function (jqXHR, textStatus, errorThrown) {
                alert(textStatus);
            }
        });
    });

    showHideDependFields = (function (fieldId, fieldName, fieldType) {
        var masterFieldsSelector = '.master-field input[type=\'checkbox\']:checked, .master-field input[type=\'radio\']:checked, .master-field select';
        $('#btn-submit').attr('disabled', 'disabled');
        $('#ajax-loading-animation').show();
        $.ajax({
            type: 'POST',
            url: siteUrl + 'index.php?option=com_pmform&task=get_depend_fields_status&field_id=' + fieldId,
            data: $(masterFieldsSelector),
            dataType: 'json',
            success: function (msg, textStatus, xhr) {
                $('#btn-submit').removeAttr('disabled');
                $('#ajax-loading-animation').hide();

                var i, hideFields, showFields;

                if (msg.hide_fields.length > 0) {
                    hideFields = msg.hide_fields.split(',');
                } else {
                    hideFields = [];
                }

                if (msg.show_fields.length > 0) {
                    showFields = msg.show_fields.split(',');
                } else {
                    showFields = [];
                }

                for (i = 0; i < hideFields.length; i++) {
                    $('#' + hideFields[i]).hide();
                }

                for (i = 0; i < showFields.length; i++) {
                    $('#' + showFields[i]).show();
                }

                //Recalculate payment amount
                calculateFormFee();
            },
            error: function (jqXHR, textStatus, errorThrown) {
                alert(textStatus);
            }
        });
    });
    /**
     * build state field
     */
    buildStateField = (function (stateFieldId, countryFieldId, defaultState) {
        if ($('#' + stateFieldId).length && $('#' + stateFieldId).is('select')) {
            var countryName;
            //set state
            if ($('#' + countryFieldId).length) {
                countryName = $('#' + countryFieldId).val();
            } else {
                countryName = '';
            }
            $.ajax({
                type: 'POST',
                url: siteUrl + 'index.php?option=com_pmform&task=get_states&country_name=' + countryName + '&field_name=' + stateFieldId + '&state_name=' + defaultState,
                success: function (data) {
                    if ($('#field_' + stateFieldId + ' .controls').length) {
                        $('#field_' + stateFieldId + ' .controls').html(data);
                    } else if ($('#field_' + stateFieldId + ' .col-md-9').length) {
                        $('#field_' + stateFieldId + ' .col-md-9').html(data);
                    } else {
//                        $('#field_' + stateFieldId + ' .uk-form-controls').html(data);
                        $('#field_' + stateFieldId + ' .controls').html(data);
                    }
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    alert(textStatus);
                }
            });
            //Bind onchange event to the country
            if ($('#' + countryFieldId).length) {
                $('#' + countryFieldId).change(function () {
                    $('#field_' + stateFieldId + ' .controls select').after('<span class="wait">&nbsp;<img src="components/com_pmform/assets/images/loading.gif" alt="" /></span>');
                    $.ajax({
                        type: 'POST',
                        url: siteUrl + 'index.php?option=com_pmform&task=get_states&country_name=' + $(this).val() + '&field_name=' + stateFieldId + '&state_name=' + defaultState,
                        success: function (data) {
                            if ($('#field_' + stateFieldId + ' .controls').length) {
                                $('#field_' + stateFieldId + ' .controls').html(data);
                            } else if ($('#field_' + stateFieldId + ' .col-md-9').length) {
                                $('#field_' + stateFieldId + ' .col-md-9').html(data);
                            } else {
                                $('#field_' + stateFieldId + ' .uk-form-controls').html(data);
                            }
                            $('.wait').remove();
                        },
                        error: function (jqXHR, textStatus, errorThrown) {
                            alert(textStatus);
                        }
                    });

                });
            }
        }//end check exits state
    });
});
